@@ -142,6 +142,10 @@ class Restore(Entity):
             "job_description": description
         }
 
+        if from_time or to_time:
+            advanced_options["timezone"] = Entity.client.timezone
+            self._LOG.info(f"Client timezone: {Entity.client.timezone}")
+
         restore_paths = []
         for path in paths:
             restore_paths.append(Entity._get_absolute_path(path, self.live_restore_path))
@@ -292,6 +296,10 @@ class Restore(Entity):
                 "job_description": f"Submitted by user [{getpass.getuser()}]"
             }
 
+        if from_time or to_time:
+            advanced_options["timezone"] = Entity.client.timezone
+            self._LOG.info(f"Client timezone: {Entity.client.timezone}")
+
         restore_paths = []
         for path in paths:
             restore_paths.append(Entity._get_absolute_path(path, self.live_restore_path))
