@@ -146,10 +146,13 @@ FileSystemSubclient Instance Attributes:
 
 	**backup_nodes**                      --  Sets backup nodes for FS Agent under Network Share clients.
 
+	**impersonate_user**                  --  Impersonation information for the subclient.
+
+
 """
 
 from __future__ import unicode_literals
-
+from base64 import b64encode
 from past.builtins import basestring
 
 from ..client import Client
@@ -1645,6 +1648,10 @@ class FileSystemSubclient(Subclient):
 
                         job_description (str)   --  Restore job description
 
+                        timezone        (str)   --  Timezone to be used for restore
+
+                            **Note** make use of TIMEZONES dict in constants.py to pass timezone
+
             Returns:
                 object - instance of the Job class for this restore job if its an immediate Job
                          instance of the Schedule class for this restore job if its a scheduled Job
@@ -1779,6 +1786,10 @@ class FileSystemSubclient(Subclient):
 
                         job_description (str)   --  Restore job description
 
+                        timezone        (str)   --  Timezone to be used for restore
+
+                            **Note** make use of TIMEZONES dict in constants.py to pass timezone
+
             Returns:
                 object - instance of the Job class for this restore job
 
@@ -2389,3 +2400,32 @@ class FileSystemSubclient(Subclient):
             raise SDKException('Subclient', '101')
 
         self.update_properties(update_properties)
+
+    @property
+    def impersonate_user(self):
+        """
+        Returns the username ONLY and applicable to Windows FS subclients only.
+        """
+        return self._subclient_properties['impersonateUser']
+
+    @impersonate_user.setter
+    def impersonate_user(self, value):
+        """
+        Sets the user impersonation information for a subclient, applicable to Windows only.
+
+        Args:
+
+            value   (dict)  --  Valid keys are 'username' and 'password'
+
+                username    (str)   --  The username
+
+                password    (str)   --  The password
+        """
+
+        update_properties = self.properties
+
+        if isinstance(value, dict):
+            update_properties["impersonateUser"]["userName"] = value["username"]
+            update_properties["impersonateUser"]["password"] = b64encode(value["password"].encode()).decode()
+
+        self.update_properties(update_properties)
\ No newline at end of file
